@@ -8,17 +8,18 @@
 #include "config.h"
 #include "edid.h"
 #include "output.h"
-#include "xrandr.h"
-#include "xrandrcrtc.h"
 #include "xrandrmode.h"
-#include "xrandroutput.h"
 #include "xrandrscreen.h"
 
 #include "../xcbwrapper.h"
 
 #include <QRect>
 #include <QScopedPointer>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 
 using namespace KScreen;
 
@@ -118,16 +119,11 @@ void XRandRConfig::applyKScreenConfig(const KScreen::ConfigPtr &config)
     const QSize newScreenSize = screenSize(config);
     const QSize currentScreenSize = m_screen->currentSize();
 
-    // When the current screen configuration is bigger than the new size (like
-    // when rotating an output), the XSetScreenSize can fail or apply the smaller
-    // size only partially, because we apply the size (we have to) before the
-    // output changes. To prevent all kinds of weird screen sizes from happening,
-    // we initially set such screen size, that it can take the current as well
-    // as the new configuration, then we apply the output changes, and finally then
-    // (if necessary) we reduce the screen size to fix the new configuration precisely.
-    const QSize intermediateScreenSize =
-        QSize(qMax(newScreenSize.width(), currentScreenSize.width()), qMax(newScreenSize.height(), currentScreenSize.height()));
-
+    // Previously we initially set such screen size, that it can take the current 
+    // as well  as the new configuration, then we apply the output changes, 
+    // and finally then (if necessary) we reduce the screen size to 
+    // fix the new configuration precisely.Now we initially disable the output, 
+    // then set the target screen size, and finally we apply the output changes.
     int neededCrtcs = 0;
     xcb_randr_output_t primaryOutput = 0;
     xcb_randr_output_t oldPrimaryOutput = 0;
@@ -238,7 +234,6 @@ void XRandRConfig::applyKScreenConfig(const KScreen::ConfigPtr &config)
     qCDebug(KSCREEN_XRANDR) << "\tChange Screen Size:" << (newScreenSize != currentScreenSize);
     if (newScreenSize != currentScreenSize) {
         qCDebug(KSCREEN_XRANDR) << "\t\tOld:" << currentScreenSize << "\n"
-                                << "\t\tIntermediate:" << intermediateScreenSize << "\n"
                                 << "\t\tNew:" << newScreenSize;
     }
 
@@ -273,24 +268,14 @@ void XRandRConfig::applyKScreenConfig(const KScreen::ConfigPtr &config)
         disableOutput(output);
     }
 
-    if (intermediateScreenSize != currentScreenSize) {
-        setScreenSize(intermediateScreenSize);
+    if (currentScreenSize != newScreenSize) {
+	for (const KScreen::OutputPtr &output : toChange) {
+             disableOutput(output);
+        }
     }
 
     bool forceScreenSizeUpdate = false;
 
-    for (const KScreen::OutputPtr &output : toChange) {
-        if (!changeOutput(output)) {
-            /* If we disabled the output before changing it and XRandR failed
-             * to re-enable it, then update screen size too */
-            if (toDisable.contains(output->id())) {
-                output->setEnabled(false);
-                qCDebug(KSCREEN_XRANDR) << "Output failed to change: " << output->name();
-                forceScreenSizeUpdate = true;
-            }
-        }
-    }
-
     for (const KScreen::OutputPtr &output : toEnable) {
         if (!enableOutput(output)) {
             qCDebug(KSCREEN_XRANDR) << "Output failed to be Enabled: " << output->name();
@@ -302,7 +287,7 @@ void XRandRConfig::applyKScreenConfig(const KScreen::ConfigPtr &config)
         setPrimaryOutput(primaryOutput);
     }
 
-    if (forceScreenSizeUpdate || intermediateScreenSize != newScreenSize) {
+    if (forceScreenSizeUpdate || currentScreenSize != newScreenSize) {
         QSize newSize = newScreenSize;
         if (forceScreenSizeUpdate) {
             newSize = screenSize(config);
@@ -310,6 +295,18 @@ void XRandRConfig::applyKScreenConfig(const KScreen::ConfigPtr &config)
         }
         setScreenSize(newSize);
     }
+
+    for (const KScreen::OutputPtr &output : toChange) {
+        if (!changeOutput(output)) {
+            /* If we disabled the output before changing it and XRandR failed
+             * to re-enable it, then update screen size too */
+            if (toDisable.contains(output->id())) {
+                output->setEnabled(false);
+                qCDebug(KSCREEN_XRANDR) << "Output failed to change: " << output->name();
+            }
+        }
+    }
+
 }
 
 void XRandRConfig::printConfig(const ConfigPtr &config) const
