@@ -11,7 +11,11 @@
 #include "screen.h"
 #include "xrandrconfig.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 
 XRandRScreen::XRandRScreen(XRandRConfig *config)
     : QObject(config)
